Crate chinchilib

Crate chinchilib 

Re-exports

pub use pixels;
pub use rgb;
pub use winit;

Structs

WinitHandler
Everyting about the window. Pixels and Window are options because they are constructed on “resume” and cannot be construted earlier

Enums

DoneStatus
Key
Mapping for the keys that are recognized. They are centered an AZERTY keyboard’s essential keys needed for games. TODO: for keys that correspondond to a character, use a unique enum variant that contains a SmolStr.

Traits

GfxApp

Functions

put_pixel